<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Lion_MultiCurrency_Admin class holds the admin functionality.
 *
 */
class Lion_MultiCurrency_Admin extends Lion_MultiCurrency {

	public function __construct() {
		// Create settings page
		add_filter( 'woocommerce_get_settings_pages', array( $this, 'add_settings' ) );

		add_action( 'admin_init', array( $this, 'admin_init' ), 99 );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		add_action( 'admin_notices', array( $this, 'admin_notices' ) );
	}

	/**
	 * Adds admin notice when currency rate is missing in exchange service
	 */
	public function admin_notices() {
		global $pagenow;

		if ( get_option( 'lionplugins_exchange_type' ) != 'service' ) {
			return;
		}

		if ( $pagenow == 'admin.php' && isset( $_GET['page'] ) && $_GET['page'] == 'wc-settings'
			&& isset( $_GET['tab'] ) && $_GET['tab'] == 'currencies'
		 ) {
			$exchange_service_rates = maybe_unserialize( get_option( 'lionplugins_exchange_service_rates' ) );
			$currencies = maybe_unserialize( get_option( 'lionplugins_currencies' ) );

			if ( $currencies && $exchange_service_rates ) {
				foreach ( $currencies as $key => $currency ) {
					if ( ! array_key_exists( $currency['code'], $exchange_service_rates['rates'] ) ) {
						$missing_currencies[] = $currency['code'];
					}
				}
			}

			if ( ! empty( $missing_currencies ) ) {
				$missing_currencies = implode( ',', $missing_currencies );
				echo '<div class="notice notice-error">
	             	<p>' . sprintf( __( 'There are currencies that are missing in the exchange rates service. The currency exchange will not work. Missing currencies: %s', 'lionplugins' ), $missing_currencies ) . '</p>
	         	</div>';
			} else if ( empty( $exchange_service_rates ) ) {
				echo '<div class="notice notice-error">
	             	<p>' . __( 'There was an error while trying to download the currencies from an external service. Please try again later.', 'lionplugins' ) . '</p>
	         	</div>';
			}
		}
	}

	/**
	 * Init.
	 */
	public function admin_init() {
	}

	public function add_settings( $settings ) {
		$settings[] = include_once LION_MULTICURRENCY_PATH . '/admin/classes/class-admin-tabs.php';

		return $settings;
	}

	public function admin_enqueue_scripts() {
		global $pagenow;

		if ( $pagenow == 'admin.php' && isset( $_GET['page'] ) && $_GET['page'] == 'wc-settings'
			&& isset( $_GET['tab'] ) && $_GET['tab'] == 'currencies' ) {
			wp_enqueue_style( 'currencies', LION_MULTICURRENCY_URL . '/admin/assets/css/currencies.css' );
			wp_enqueue_script( 'currencies', LION_MULTICURRENCY_URL . '/admin/assets/js/currencies.js', array( 'jquery' ) );
			wp_enqueue_script( 'uploader', LION_MULTICURRENCY_URL . '/admin/assets/js/uploader.js', array( 'jquery' ) );

			$javascript_vars = array(
				'no_rows_selected' => __( 'No row(s) selected', 'lionplugins' ),
				'left' => __( 'Left', 'lionplugins' ),
				'right' => __( 'Right', 'lionplugins' ),
				'left_with_space' => __( 'Left with space', 'lionplugins' ),
				'right_with_space' => __( 'Right with space', 'lionplugins' ),
				'upload_icon' => __( 'Upload Icon', 'lionplugins' ),
				'use_this_file' => __( 'Use this file', 'lionplugins' ),
				'plugin_url' => LION_MULTICURRENCY_URL,
			);
			wp_localize_script( 'currencies', 'currencies', $javascript_vars );

			wp_enqueue_script( 'currencies' );

			wp_enqueue_media();
		}
	}
}

new Lion_MultiCurrency_Admin();
