<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Lion_MultiCurrency_Currencies_Admin_Settings extends WC_Settings_Page {

	public function __construct() {
		$this->id = 'currencies';
		$this->label = __( 'Currencies', 'lionplugins' );

		add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_page' ), 99 );
		add_action( 'woocommerce_sections_' . $this->id, array( $this, 'output_sections' ) );
		add_action( 'woocommerce_settings_' . $this->id, array( $this, 'output' ) );
		add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'save' ) );
	}

	/**
	 *  Get sections
	 *
	 *  @return array
	 */
	public function get_sections() {
		$exchange_type = ( get_option( 'lionplugins_exchange_type' ) ) ? get_option( 'lionplugins_exchange_type' ) : '';

		// Must contain more than one section to display the links
		// Make first element's key empty ('')
		$sections = array(
			'' => __( 'General', 'lionplugins' ),
			'currencies' => __( 'Currencies', 'lionplugins' ),
		);

		switch ( $exchange_type ) {
			case 'table':
				$sections['exchange_rates_table'] = __( 'Exchange rates', 'lionplugins' );
				break;

			case 'service':
				$sections['exchange_service'] = __( 'Exchange service', 'lionplugins' );
				break;
		}

		return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
	}

	/**
	 *  Get settings array
	 *
	 *  @return array
	 */
	public function get_settings( $current_section = '' ) {
		global $current_section;
		$settings = array();
		if ( $current_section == 'currencies' ) {
			$settings = array();
		} elseif ( $current_section == 'exchange_rates' ) {
			$settings = array();
		} elseif ( $current_section == 'exchange_service' ) {
			// Exchange service
			$settings = array(
				array(
					'title' => '',
					'type'  => 'title',
					'id'    => 'exchange_service_options',
				),
				array(
					'title'           => __( 'Exchange service', 'lionplugins' ),
					'desc'            => __( 'Make sure the currency codes you use have exchange rates in the API' ),
					'id'              => 'lionplugins_exchange_service',
					'type'            => 'radio',
					'options'         => array(
						'exchangeratesapi'     => __( 'exchangeratesapi.io API', 'lionplugins' ),
					),
					'autoload'        => false,
					'desc_tip'        => true,
					'show_if_checked' => 'option',
					'default'       => 'exchangeratesapi',
				),
				array(
					'type' => 'sectionend',
					'id'   => 'exchange_service_options',
				),
			);
		} else {
			// General
			$settings = array(
				array(
					'title' => '',
					'type'  => 'title',
					'id'    => 'currency_options',
				),
				array(
					'title'           => __( 'Foreign exchange rates', 'lionplugins' ),
					'desc'            => '',
					'id'              => 'lionplugins_exchange_type',
					'type'            => 'radio',
					'options'         => array(
						'table'     => __( 'I\'ll use exchange rates table', 'lionplugins' ),
						'service'     => __( 'I\'ll use exchange rates service', 'lionplugins' ),
					),
					'autoload'        => false,
					'desc_tip'        => false,
					'show_if_checked' => 'option',
					'default'       => 'table',
				),
				array(
					'title'         => __( 'Checkout', 'lionplugins' ),
					'desc'          => __( 'Allow customers to place orders in their current currency', 'lionplugins' ),
					'id'            => 'lionplugins_enable_multicurrency_checkout',
					'default'       => 'no',
					'type'          => 'checkbox',
					'checkboxgroup' => 'start',
					'autoload'      => false,
					'desc_tip'      => __( 'Your payment provider must accept different currencies.', 'lionplugins' ),
				),
				array(
					'type' => 'sectionend',
					'id'   => 'currency_options',
				),
			);
		}
		return apply_filters( 'woocommerce_get_settings_' . $this->id, $settings );
	}

	/**
	 *  Output the settings
	 */
	public function output() {
		global $current_section;

		if ( $current_section == 'currencies' ) {
			$template_data = array(
				'currencies' => get_option( 'lionplugins_currencies' ),
				'default_currency' => get_option( 'lionplugins_default_currency' ),
				'currency_position' => $this->default_currency_position(),
			);

			include_once LION_MULTICURRENCY_PATH . '/admin/views/currency-table.php';
		} elseif ( $current_section == 'exchange_rates_table' ) {
			include_once LION_MULTICURRENCY_PATH . '/admin/views/exchange-rates.php';
		} else {
			$settings = $this->get_settings( $current_section );
			WC_Admin_Settings::output_fields( $settings );
		}
	}

	private function default_currency_position() {
		$currency_pos = get_option( 'woocommerce_currency_pos' );

		switch ( $currency_pos ) {
			case 'left':
				$result = __( 'Left', 'lionplugins' );
				break;
			case 'left_space':
				$result = __( 'Left with space', 'lionplugins' );
				break;
			case 'right':
				$result = __( 'Right', 'lionplugins' );
				break;
			case 'right_space':
				$result = __( 'Right with space', 'lionplugins' );
				break;
		}

		return $result;
	}

	/**
	 *  Process save
	 *
	 *  @return array
	 */
	public function save() {
		global $current_section;

		if ( $current_section == 'currencies' ) {
			// Save default currency
			$default_currency = array_map( 'sanitize_text_field', $_POST['default_currency'] );
			$default_currency['code'] = get_woocommerce_currency();

			update_option( 'lionplugins_default_currency', $default_currency );

			// Save currencies
			$currencies_raw_data = wp_unslash( (array) $_POST['currencies'] );
			$currencies = array();

			if ( $currencies_raw_data ) {
				foreach ( $currencies_raw_data as $fields => $currencies_settings ) {
					foreach ( $currencies_settings as $key => $settings ) {
						if ( $fields == 'code' && empty( $settings ) ) {
							$digits = 3;
							$random = rand( pow( 10, $digits - 1 ), pow( 10, $digits ) - 1 );

							$settings = 'RANDOM_' . $random;
						}

						$currencies[ sanitize_text_field( $key ) ][ sanitize_text_field( $fields ) ] = sanitize_text_field( $settings );
					}
				}
			}

			update_option( 'lionplugins_currencies', $currencies );
		} elseif ( $current_section == 'exchange_rates_table' ) {
			$exchange_rates_raw_data = wp_unslash( (array) $_POST['exchange_rates'] );
			$exchange_rates = array();

			foreach ( $exchange_rates_raw_data as $fields => $exchange_rates_settings ) {
				foreach ( $exchange_rates_settings as $key => $settings ) {
					$exchange_rates[ sanitize_text_field( $key ) ][ sanitize_text_field( $fields ) ] = preg_replace( '/[^\\d.]+/', '', sanitize_text_field( $settings ) );
				}
			}

			update_option( 'lionplugins_exchange_rates', $exchange_rates );
		} else {
			$settings = $this->get_settings( $current_section );
			WC_Admin_Settings::save_fields( $settings );
		}

		if ( $current_section ) {
			do_action( 'woocommerce_update_options_' . $this->id . '_' . $current_section );
		}
	}
}

new Lion_MultiCurrency_Currencies_Admin_Settings();
