<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Lion_MultiCurrency_Currency extends Lion_MultiCurrency {

	public function __construct() {
		add_action( 'woocommerce_init', array( $this, 'create_cookie' ) );
		add_action( 'woocommerce_cart_loaded_from_session', array( $this, 'refresh_the_cart' ) );
		add_action( 'woocommerce_checkout_create_order', array( $this, 'order_currency' ), 10, 2 );
		add_action( 'wp_head', array( $this, 'wc_fragment_refresh' ) );

		add_filter( 'woocommerce_currency_symbol', array( $this, 'currency_symbol' ), 10, 2 );
		add_filter( 'woocommerce_currencies', array( $this, 'currencies' ) );
		add_filter( 'pre_option_woocommerce_currency_pos', array( $this, 'woocommerce_currency_pos' ) );
	}

	/**
	 * Add new currencies to WooCommerce.
	 * 
	 */
	public function currencies( $currencies ) {
		$new_currencies = get_option( 'lionplugins_currencies' );

		if ( $new_currencies ) {
			foreach ( $new_currencies as $new_currency ) {
				$currencies[ $new_currency['code'] ] = __( $new_currency['code'], 'lionplugins' );
			}
		}

		return $currencies;
	}

	/**
	 * Change the currency position.
	 * 
	 */
	public function woocommerce_currency_pos( $currency_pos ) {
		$new_currencies = get_option( 'lionplugins_currencies' );

		if ( $new_currencies ) {
			foreach ( $new_currencies as $new_currency ) {
				if ( $this->get_current_currency() == $new_currency['code'] ) {
					$currency_pos = $new_currency['position'];
				}
			}
		}

		return $currency_pos;
	}

	/**
	 * Create a cookie.
	 * 
	 */
	public function create_cookie() {
		if ( isset( $_GET['lp_currency'] ) ) {
			$current_currency = sanitize_text_field( $_GET['lp_currency'] );

			$default_currency = get_option( 'lionplugins_default_currency' );
			$new_currencies = get_option( 'lionplugins_currencies' );

			if ( $new_currencies ) {
				foreach ( $new_currencies as $new_currency ) {
					$currency_codes[] = strtolower( $new_currency['code'] );
				}
			}

			$currency_codes[] = strtolower( $default_currency['code'] );

			// Check if currency code exists in the currencies table
			if ( in_array( strtolower( $current_currency ), $currency_codes ) ) {
				wc_setcookie( 'lp_currency', $current_currency );
			}
		}
	}

	/**
	 * Refresh the mini cart.
	 * 
	 */
	public function wc_fragment_refresh() {
		if ( isset( $_GET['lp_currency'] ) ) {
			echo '<script>
			 jQuery(window).load(function(e) {
			 	jQuery(document.body).trigger("wc_fragment_refresh");
			 });
			</script>';
		}
	}

	/**
	 * Currency symbol.
	 * 
	 */
	public function currency_symbol( $currency_symbol, $currency ) {
		$new_currencies = get_option( 'lionplugins_currencies' );

		if ( $new_currencies ) {
			foreach ( $new_currencies as $new_currency ) {
				if ( ! empty( $new_currency['code'] ) ) {
					if ( $this->get_current_currency() == $new_currency['code'] ) {
						return esc_attr( $new_currency['symbol'] );
					}
				}
			}
		}

		return $currency_symbol;
	}

	/**
	 * Order currency.
	 * 
	 */
	public function order_currency( $order, $data ) {
		if ( get_option( 'lionplugins_enable_multicurrency_checkout' ) == 'yes' ) {
			$order->set_currency( $this->get_current_currency() );
		}
	}

	/**
	 * Refresh the loaded cart from session after changing the currency
	 * 
	 */
	function refresh_the_cart() {
		if ( isset( $_GET['lp_currency'] ) ) {
			WC()->cart->calculate_shipping();
			WC()->cart->calculate_totals();
		}
	}
}

new Lion_MultiCurrency_Currency();
