<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Lion_MultiCurrency_Exchange_Service extends Lion_MultiCurrency {

	public function __construct() {
		add_action( 'lionplugins_exchange_service', array( $this, 'get_currency_rates' ) );
		add_action( 'woocommerce_settings_save_general', array( $this, 'woocommerce_settings_save_general' ) );
	}

	/**
	 * Update currency rates if default currency has changed
	 *
	 */
	public function woocommerce_settings_save_general( $array ) {
		// Update exchange rates
		if ( get_option( 'lionplugins_exchange_type' ) == 'service' ) {
			$service_exchange_rates = maybe_unserialize( get_option( 'lionplugins_exchange_service_rates' ) );

			if ( $service_exchange_rates ) {
				if ( $service_exchange_rates['base'] != get_woocommerce_currency() ) {
					$this->get_currency_rates();
				}
			}
		}

		// Update default currency
		$default_currency = get_option( 'lionplugins_default_currency' );
		if ( ! empty( $default_currency ) ) {
			if ( $default_currency['code'] != get_woocommerce_currency() ) {
				$default_currency = array(
					'code' => get_woocommerce_currency(),
					'symbol' => '',
					'name' => get_woocommerce_currency(),
					'position' => get_option( 'woocommerce_currency_pos' ),
					'icon_url' => '',
				);

				update_option( 'lionplugins_default_currency', $default_currency );
			}
		}
	}

	/**
	 * Get currency exchange rates from the external service
	 *
	 */
	public function get_currency_rates() {
		$api_endpoint = add_query_arg( 'base', get_woocommerce_currency(), 'https://api.exchangeratesapi.io/latest' );

		$response = wp_remote_get( $api_endpoint );

		if ( is_array( $response ) ) {
			$header = $response['headers'];
			$body = $response['body'];

			if ( $body ) {
				$exchange_rates = json_decode( $body, true );

				update_option( 'lionplugins_exchange_service_rates', maybe_serialize( $exchange_rates ) );
			}
		}
	}
}

new Lion_MultiCurrency_Exchange_Service();
