<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Lion_MultiCurrency_Product_Price extends Lion_MultiCurrency {

	public function __construct() {
		add_filter( 'woocommerce_product_get_price', array( $this, 'get_product_price' ), 10, 2 );
		add_filter( 'woocommerce_product_get_regular_price', array( $this, 'get_regular_price' ), 10, 2 );
		add_filter( 'woocommerce_product_get_sale_price', array( $this, 'get_sale_price' ), 10, 2 );
		add_filter( 'woocommerce_variation_prices_price', array( $this, 'variation_prices_price' ), 10, 3 );
		add_filter( 'woocommerce_variation_prices_regular_price', array( $this, 'variation_prices_regular_price' ), 10, 3 );
		add_filter( 'woocommerce_variation_prices_sale_price', array( $this, 'variation_prices_sale_price' ), 10, 3 );
		add_filter( 'woocommerce_product_variation_get_price', array( $this, 'get_product_price' ), 10, 2 );
		add_filter( 'woocommerce_product_variation_get_regular_price', array( $this, 'get_regular_price' ), 10, 2 );
		add_filter( 'woocommerce_product_variation_get_sale_price', array( $this, 'get_sale_price' ), 10, 2 );
		add_filter( 'woocommerce_get_variation_prices_hash', array( $this, 'woocommerce_get_variation_prices_hash' ), 10, 3 );
	}

	/**
	 * Get price for currency
	 * 
	 */
	private function get_price( $product_id, $type = 'regular_price' ) {
		$exchange_type = ( get_option( 'lionplugins_exchange_type' ) ) ? get_option( 'lionplugins_exchange_type' ) : '';

		$exchange_rates = array();
		switch ( $exchange_type ) {
			case 'table':
				$exchange_rates = get_option( 'lionplugins_exchange_rates' );
				break;

			case 'service':
				$service_exchange_rates = maybe_unserialize( get_option( 'lionplugins_exchange_service_rates' ) );

				if ( ! empty( $service_exchange_rates ) && is_array( $service_exchange_rates ) ) {
					foreach ( $service_exchange_rates['rates'] as $key => $rate ) {
						$exchange_rates[ $key ]['rate'] = $rate;
					}
				}
				break;
		}

		if ( $exchange_rates ) {
			if ( array_key_exists( $this->get_current_currency(), $exchange_rates ) ) {
				$rate = $exchange_rates[ $this->get_current_currency() ]['rate'];

				if ( ! is_numeric( $rate ) || $rate <= 0 ) {
					return false;
				}

				if ( $type == 'regular_price' ) {
					$price = get_post_meta( $product_id, '_regular_price', true ) * $rate;
				} else {
					$price = get_post_meta( $product_id, '_sale_price', true ) * $rate;
				}

				return $price;
			}
		}
	}

	/**
	 * Filter the active product price
	 * 
	 */
	public function get_product_price( $price, $product ) {
		$product_sale_price = $this->get_price( $product->get_id(), 'sale_price' );
		$product_regular_price = $this->get_price( $product->get_id(), 'regular_price' );

		if ( $product_sale_price ) {
			return $product_sale_price;
		} elseif ( $product_regular_price ) {
			return $product_regular_price;
		}

		return $price;
	}

	/**
	 * Filter regular price
	 * 
	 */
	public function get_regular_price( $price, $product ) {
		$product_regular_price = $this->get_price( $product->get_id(), 'regular_price' );

		if ( $product_regular_price ) {
			return $product_regular_price;
		}

		return $price;
	}

	/**
	 * Filter sale price
	 * 
	 */
	public function get_sale_price( $price, $product ) {
		$product_sale_price = $this->get_price( $product->get_id(), 'sale_price' );

		if ( $product_sale_price ) {
			return $product_sale_price;
		}

		return $price;
	}

	/**
	 * Filter variation price range
	 * 
	 */
	public function variation_prices_price( $price, $variation, $product ) {
		$product_sale_price = $this->get_price( $variation->get_id(), 'sale_price' );
		$product_regular_price = $this->get_price( $variation->get_id(), 'regular_price' );

		if ( $product_sale_price ) {
			return $product_sale_price;
		} elseif ( $product_regular_price ) {
			return $product_regular_price;
		}

		return $price;
	}

	/**
	 * Variation price range regular price
	 * 
	 */
	public function variation_prices_regular_price( $price, $variation, $product ) {
		$product_regular_price = $this->get_price( $variation->get_id(), 'regular_price' );

		if ( $product_regular_price ) {
			return $product_regular_price;
		}

		return $price;
	}

	/**
	 * Variation price range sale price
	 * 
	 */
	public function variation_prices_sale_price( $price, $variation, $product ) {
		$product_sale_price = $this->get_price( $variation->get_id(), 'sale_price' );

		if ( $product_sale_price ) {
			return $product_sale_price;
		}

		return $price;
	}

	/**
	 * Variation hash
	 * 
	 */
	public function woocommerce_get_variation_prices_hash( $price_hash, $product, $for_display ) {
		return $this->get_current_currency();
	}
}

new Lion_MultiCurrency_Product_Price();