<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Lion_MultiCurrency_Widget extends WP_Widget {

	public function __construct() {
		parent::__construct(
			'lionplugins_multicurrency_widget',
			__( 'Multi Currency For WooCommerce', 'lionplugins' ),
			array(
				'description' => __( 'Adds Multi Currency dropdown.', 'lionplugins' ),
				'customize_selective_refresh' => true,
			)
		);
	}

	// The widget form
	public function form( $instance ) {
		// Set widget defaults
		$defaults = array(
			'title'    => '',
			'type'  => '',
			'style' => '',
		);

		// Parse current settings with defaults
		extract( wp_parse_args( (array) $instance, $defaults ) ); ?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title', 'lionplugins' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php _e( 'Show icon', 'lionplugins' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'type' ); ?>" id="<?php echo $this->get_field_id( 'type' ); ?>" class="widefat">
			<?php

			$options = array(
				''        => __( 'Select', 'lionplugins' ),
				'icon_and_currency_code' => __( 'Icon and currency code', 'lionplugins' ),
				'icon' => __( 'Icon', 'lionplugins' ),
				'currency_code' => __( 'Currency code', 'lionplugins' ),
			);

			// Loop through options and add each one to the select dropdown
			foreach ( $options as $key => $name ) {
				echo '<option value="' . esc_attr( $key ) . '" id="' . esc_attr( $key ) . '" ' . selected( $type, $key, false ) . '>' . $name . '</option>';
			}
			?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'style' ); ?>"><?php _e( 'Style', 'lionplugins' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'style' ); ?>" id="<?php echo $this->get_field_id( 'style' ); ?>" class="widefat">
			<?php
			$options = array(
				''        => __( 'Select', 'lionplugins' ),
				'dropdown' => __( 'Dropdown', 'lionplugins' ),
				'list' => __( 'List', 'lionplugins' ),
			);

			// Loop through options and add each one to the select dropdown
			foreach ( $options as $key => $name ) {
				echo '<option value="' . esc_attr( $key ) . '" id="' . esc_attr( $key ) . '" ' . selected( $style, $key, false ) . '>' . $name . '</option>';
			}
			?>
			</select>
		</p>

		<?php
	}

	// Update widget settings
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title']    = isset( $new_instance['title'] ) ? wp_strip_all_tags( $new_instance['title'] ) : '';
		$instance['type']   = isset( $new_instance['type'] ) ? wp_strip_all_tags( $new_instance['type'] ) : '';
		$instance['style']   = isset( $new_instance['style'] ) ? wp_strip_all_tags( $new_instance['style'] ) : '';

		return $instance;
	}

	// Display the widget
	public function widget( $args, $instance ) {
		extract( $args );
		$title    = isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
		$type   = isset( $instance['type'] ) ? $instance['type'] : '';
		$style   = isset( $instance['style'] ) ? $instance['style'] : '';

		$currencies = lion_multicurrency_get_currencies();

		// Template
		include_once LION_MULTICURRENCY_PATH . '/templates/widget.php';
	}
}

function lionplugins_multicurrency_widget() {
	register_widget( 'Lion_MultiCurrency_Widget' );
}
add_action( 'widgets_init', 'lionplugins_multicurrency_widget' );
